==> haskell-doctemplates-0.1.0.2-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctemplates
version: 0.1.0.2
id: doctemplates-0.1.0.2-BO6TgXRW3jELAeQco34C0g
key: doctemplates-0.1.0.2-BO6TgXRW3jELAeQco34C0g
license: BSD3
copyright: 2016 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/doctemplates#readme
synopsis: Pandoc-style document templates
description:
    Please see README.md
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Text.DocTemplates
abi: 5bab9f957c9b3102fb23ba7ece9b4fdf
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/doctemplates-0.1.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/doctemplates-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-doctemplates
hs-libraries: HSdoctemplates-0.1.0.2-BO6TgXRW3jELAeQco34C0g
depends:
    aeson-1.1.2.0-H9d5B7Pgw9tIbOpl8Ot3sY base-4.9.1.0
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0 bytestring-0.10.8.1
    containers-0.5.7.1 parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR
    scientific-0.3.4.15-Is44CvKqXBF5ugVqyS94hI
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock
haddock-html: /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctemplates-0.1.0.2-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctemplates
version: 0.1.0.2
id: doctemplates-0.1.0.2-1ntaIXY0r9P8vtc0JjInuw
key: doctemplates-0.1.0.2-1ntaIXY0r9P8vtc0JjInuw
license: BSD3
copyright: 2016 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/doctemplates#readme
synopsis: Pandoc-style document templates
description:
    Please see README.md
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Text.DocTemplates
abi: 5ccd2984501e6e8afe08ba8558512028
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/doctemplates-0.1.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/doctemplates-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-doctemplates
hs-libraries: HSdoctemplates-0.1.0.2-1ntaIXY0r9P8vtc0JjInuw
depends:
    aeson-1.1.2.0-2Tms2Hc2yE36x3yS5aZqW9 base-4.9.1.0
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0 bytestring-0.10.8.1
    containers-0.5.7.1 parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR
    scientific-0.3.5.0-7hRLtQzMvnkCQbsJuyPHcq
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock
haddock-html: /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
